## v0.7.0 (2025-02-05)

### ✨ Features

- add component fit and plot (#20)
- enhance FitAccessor to accept additional keyword arguments in fit method
- add ArrAccessor for getting fit_arr values (#18)
- add visualization of fit stat to DisplayAccessor (#17)

[main 8e5a6be] bump: version 0.6.0 → 0.7.0
 2 files changed, 2 insertions(+), 2 deletions(-)

